OpenBCM V1.13 (Linux)

Packet Radio Mailbox

DB0FHN

[JN59NK Nuernberg]

 Login: GUEST





  
DF1ND  > BLIND    29.11.97 00:05l 930 Lines 41249 Bytes #-10532 (0) @ DL
BID : SB7DB0MAK08Q
Read: DO6NP GUEST
Subj: terminw.dok
Path: DB0AAB<DB0SL<DB0RGB<DB0MAK
Sent: 971128/2016z @:DB0MAK.#BAY.DEU.EU [Marktredwitz, JO60BA] Bcm1.39w7
From: DF1ND @ DB0MAK.#BAY.DEU.EU  (Marco)
To:   BLIND @ DL
X-BID: SB7DB0MAK08Q

                          ä

 TERMINWÄCHTER
 Version 3.0 BRL


 Programmautor:
 Markus Wendel, Limburg
 (Rufzeichen: DG1FBA)


 Dokumentation und Bedienungsanleitung:
     Gerhard Reiter, Hannover  und  Klaus Hahn, Münster


 Stand: Juli 1996


 ZudiesemProgramm

 Der "Terminwächter" wurde auf Anregung blinder PC-Benutzer entwickelt und
 dank der Mithilfe vieler Anwender verbessert und erweitert.

 Die Koordination der Anregungen im Kontakt mit dem Autor und das Verteilen
 der neuen Versionen an die Nutzer hat Gerhard Reiter, Hannover, übernommen.

 Dem Programmautor gilt besonderer Dank dafür, daß er seine Entwicklung auf
 die Bedürfnisse blinder PC-Nutzer eingerichtet hat. So wurde dieses Programm
 zu einem Wertvollen Utility, an dessen Verbesserung ständig gearbeitet
 wird. Es steht allen sehgeschädigten Computernutzern kostenlos zur
 Verfügung, doch möchten wir Ihnen ein freiwilliges Anerkennungshonorar
 herzlich empfehlen. Auf den Begleitbrief auf der Programmdiskette sei
 verwiesen.

 Der "Terminwächter" darf in dieser Version nach ausdrücklicher Bestimmung
 des Autors kopiert und weitergegeben, aber nicht verkauft werden!


 Leistungsmerkmale

 Der Terminwächter (TW) ist ein vollwertiger Terminkalender und -planer. Er
 übertrifft bei weitem die konventionellen Möglichkeiten blinder Menschen zur
 Terminverwaltung auf der Basis von Papier und Punktschrift. Der TW ist auch
 den komplexen Anforderungen einer beruflichen Terminorganisation gewachsen:


 - Verwendeter Code: ASCII

 - Zugänglich für Sprachausgaben und Braille-Zeilen (auch mit weniger als 40
   Stellen)

 - einfacher Programmaufruf mit "TERMIN" plus Parameter

 - klare Nutzerführung

 - Statusangaben in Zeile 1, Eingabehinweise in Zeile 24/25

 - komfortables Erfassen neuer und Verändern bestehender Termine

 - bis zu 2 Zeilen Texteintrag pro Termin

 - alphanumerisches Sortieren der Termine

 - Kategorisieren der Termine in vier Gruppen

 - Monatsüberblick über die Terminlage

 - genauer Einzelüberblick mit Korrekturmöglichkeiten

 - Suchfunktion mit Zusammenstellen gleichartiger Termine

 - Integration von Dauerterminen (Geburtstagskalender)

 - Anzeige der heute aktuellen und der demnächst anstehenden Termine bei
   Start des PC

 - Herausfiltern und separates Abspeichern erledigter Termine

 - Berechnen und Übernehmen turnusmäßig wiederkehrender Termine

 - Datums-, Wochentags- und Feiertagsübersicht und -berechnung von 1901 -
   2064

 - automatisches parametergesteuertes Backup der Terminliste


 - Notizblock und Adreßdatei als Zubehör.



 blindentechnische Besonderheiten:


  1. Alle aktuellen Meldungen und Ausgaben werden durch den Schreibcursor
     stets an die Braillezeile gekoppelt.

 2. Soweit möglich sind alle Anzeigen linksbündig auf Spalte 2 sortiert (in
    Spalte 1 steht der Cursor).

 3. Der Cursor verdeckt in der Brailledarstellung keinen Buchstaben und keine
     Ziffer.


 4. Die Anwendung wird durch akustische Signale unterstützt:

    - Hinweissignale bei wichtigen Programmeldungen (abschaltbar);
 - Fehlersignale bei Eingabefehlern;
 - Bestätigungssignale bei "stillen" Programmabläufen, deren Vollzug auf der
   Zeile nicht abgelesen werden kann.


 5. Das Prinzip
    - Return = ENTER = Eingabebestätigung,
    - ESCAPE = Rückschritt zur vorherigen Ebene und
    - "beliebige Taste" = Weiterführung in einer Auflistung bzw. Übergang zur
       nächsten Funktion
     wurde konsequent durchgeführt.


 6. Dokumentation und Bedienungsanleitung zur jeweils gültigen Version
    werden in Langschrift und Blindenkurzschrift auf Diskette mitgeliefert,
    ebenso die Update-Dokumentationen zu neuen Versionen.


 In dieser Dokumentation ist der Einfachheit halber immer nur von der Ausgabe
 auf der Braille-Zeile die Rede. Die Ausgabe über Sprache oder Großbild ist
 natürlich auch möglich.


 Achtung Kurzschrift-Leser: In diesem Text sind alle Befehlszeileneinträge
 und Parameter konsequent in Computer-Braille geschrieben. Sie finden deshalb
 auch gelegentlich im fortlaufenden Text ohne Vorwarnung kurze Angaben in
 Computer-Braille.



 1.Installation und Update

 1.1 Altanwender des TW erhalten bei neuen Programmversionen eine neue
 TERMIN.EXE, die sie einfach anstelle der bisherigen Version übernehmen.
 Alles andere bleibt unverändert, es sei denn, die dazugehörende UPDATE.DOK
 (bzw. UPDATE.BRL) enthält andere Anweisungen.

 Der Rest dieses Kapitels betrifft Erstanwender.


 1.2 Neueinsteiger legen zunächst im Hauptverzeichnis Ihrer Festplatte ein
 Unterverzeichnis (UV) an; Namensvorschlag: TERMPLAN oder TP. Kopieren Sie
 dann die TERMIN.EXE in dieses UV. das Programm wird alle Dateien, die es nun
 anlegt, hier abspeichern.

 Nun brauchen Sie erst "Spielmaterial", um die Möglichkeiten des TW
 kennenzulerenen. Befolgen Sie hierzu die nachstehenden Anweisungen
 korrekt, auch wenn Sie die Bedeutung der Parameter und Menüpunkte noch nicht
 verstehen. Andernfalls müßten Sie diese Anleitung "trocken" bis zum Ende
 durcharbeiten.

 Wechseln Sie auf der DOS-Ebene in das UV TP und geben Sie ein:

 TERMIN -o

 Sie werden bei diesem Erstaufruf nach Ihrem Namen gefragt, den Sie eintragen
 und mit Return bestätigen. Das Programm legt jetzt die Datei TERMIN.LOG an
 (vgl. Kapitel 3). Beim Aufruf der Terminüberwachung werden Sie zukünftig im
 Kopf des Bildschirms mit diesem Eintrag begrüßt, wobei dieser Gruß den
 verschiedenen Tageszeiten angepaßt ist.

 Jetzt erhalten Sie das Menü des Termin-Editors. Gehen Sie erst mal einfach
 mit der Pfeiltaste nach unten auf den Punkt "3 = Eingabe von neuen Terminen"
 und bestätigen Sie mit ENTER. Es erscheint "Datum:" mit dem Cursor als
 Eingabeaufforderung. Tragen Sie hier das heutige Datum in zweistelliger
 Schreibweise ein: tt.mm.jj und bestätigen Sie mit return. Es erscheint die
 Eingabeaufforderung "Text:". Hier können Sie bis zu einer Zeile Text eintragen
 und mit return abschließen. Sie erhalten wieder die Eingabeaufforderung
 "Datum:". Tragen Sie sich noch einige Termine ein, auch mit dem gestrigen und
 mit kommenden Tagen, aber (noch) nicht mehrere Termine für einen Tag. Den
 Texteintrag können Sie auch mit der Uhrzeit beginnen. Wenn Sie einige Termine
 eingegeben haben, gehen Sie bitte mit ESCAPE bis zum DOS-Prompt
 (Unterverzeichnis TP) zurück.


 1.3 Geben Sie nun ein:

   termin -w

 Es ertönt ein Klingelzeichen, und der heutige Termin wird angezeigt. Drücken
 Sie eine beliebige Taste, und es erscheint der nächste Termin. Gehen Sie mit
 der Pfeiltaste nach unten, und sie finden den übernächsten (wenn Sie genügend
 Einträge gemacht haben). Mit der Zeile können Sie den Bildschirm einmal in Ruhe
 auslesen. Mit beliebiger Taste kommen Sie zurück zum DOS-Prompt.


 1.4 Binden Sie nun den Programmaufruf direkt in der AUTOEXEC.BAT an vorletzter
 Stelle ein, bevor Sie dann an letzter Stelle in Ihr gewohntes Arbeitsmenü
 kommen. So werden Sie beim Start Ihres PC zunächst an fällige Termine erinnert,
 erhalten eine Übersicht über eine von Ihnen festgelegte Anzahl von kommenden
 Terminen und bekommen eine Meldung von Terminen, die das Programm noch
 nicht anzeigen konnte, weil Sie Ihren Rechner einige Tage lang nicht
 eingeschaltet hatten. Dies alles ist mit akustischen Signalen verbunden.

 Ihre AUTOEXEC.BAT könnte an dieser Stelle etwa so aussehen:

 CD \

 CD TP

 TERMIN -K5 -W

 CD \

 Eintrag Ihres Arbeitsprogramms

 Welche Parameter Sie endgültig setzen, entscheiden Sie, wenn Sie die
 Dokumentation ganz durchgearbeitet und erste Erfahrungen gesammelt haben.

 Starten Sie jetzt Ihren PC neu. Ab jetzt wird bei jedem Start jeder
 "aktuelle Termin" auf der Zeile stehen. Betätigen Sie eine beliebige Taste.
 Sind mehrere Termine für den gleichen Tag eingetragen, so meldet sich der
 nächste in gleicher Weise, bis alle heutigen Termine aufgelistet sind. Ist
 kein weiterer aktueller Termin vorhanden, so bekommen Sie die Termine der
 folgenden Tage aufgelistet. Die Zahl bestimmen Sie durch den Parameter -k.
 Zugleich werden Ihnen etwaige seit dem letzten Programmaufruf versäumte
 Termine durch einen Dreiklang angekündigt und oberhalb der cursorzeile
 aufgelistet.


 2.Parameter
 Alle Parameter können wahlweise mit einem Bindestrich oder einem
 Schrägstrich eingeleitet werden. Der Einfachheit halber wird in dieser
 Dokumentation immer der Bindestrich verwendet.



 -A Adreßdateiverwaltung
     Mit diesem Parameter erhalten Sie eine einfache, aber praktische
     Möglichkeit, sich Anschriften, Telefonnummern usw. zu notieren, diese zu
     ändern oder zu löschen. Die Option ist unterteilt in einen normalen
     Anschriftenbereich und QSL-Adressen (für Funkamateure). Sie können diese
     Option auch über Punkt 7 des Editormenüs aufrufen (s. Kapitel 4).

 -b Aufruf des Notizblocks
     Zeigt zunächst die mit dem Parameter -kx oder -ktx vorbestimmte
     Anzahl der kommenden Termine, sodann kann Text editiert werden, das
     Programm legt die Datei TERMIN.NZB an. Der Parameter kann in den
     Befehlseintrag in der AUTOEXEC.BAT aufgenommen werden, aber nicht
     zusammen mit dem Aufruf des Editors. Aufruf auch über Menüpunkt 9 des
     Termineditors (s. Kapitel 4)

 -H Hilfe: Anzeige dieser Parameterliste in Kurzfassung

 -KX die Anzahl der künftigen Termine kann vorgegeben werden; ohne
     diesen Parameter werden die nächsten beiden gezeigt. Mit -K und
     nachfolgender Ziffer kann diese Anzahl erhöht werden, also etwa: -K5.
     Hier spielt es keine Rolle, wie groß die Zeitspanne bis zu diesen
     Terminen ist.

 -ktx Anders als bei -kx werden nicht die x nächsten Termine
     aufgelistet, sondern die Termine der x nächsten Tage. Diese Option
     ist dann wichtig, wenn Sie häufig für einen Tag mehrere Termine
     eingetragen haben. Wenn z.B. -kt5 gesetzt ist, endet die Anzeige nicht
     nach dem 5. Termin, sondern nach dem letzten Termin des 5. Tages.
     Sind für die nächsten 5 Tage kaum oder keine Termine eingetragen, ist die
     Anzeige entsprechend kurz. Man kann sich so z.B. die Übersicht immer für
     eine Woche im Voraus verschaffen.

 -L Tag und Uhrzeit aller Aufrufe der Terminüberwachung
     werden in der TERMIN.LOG wie in einem Logbuch verzeichnet. Unabhängig von
     diesem Parameter wird bei Programmaufruf im Kopfteil des Bildschirms die
     letzte Nutzung mit Datum und Uhrzeit angegeben. Ohne diesen Parameter
     enthält die TERMIN.LOG nur Ihren Namen und Tag und Zeit des letzten
     Aufrufs.

 -n alle akustischen Signale (außer Warnungen bei der Termineingabe)
     werden unterdrückt

 -T der Termineditor wird aufgerufen (s. Kapitel 4).

 -O Aufruf des TW-Editors mit automatischem Wochentagseintrag;
     Wird anstelle von -T gesetzt. Das Programm setzt dann bei jedem
     Neueintrag den Wochentag zum Datum. Das gilt natürlich nicht für jährlich
     wiederkehrende Termine.


 -W der jeweils aktuelle, also der "heutige" Termin wird auf der
     Braille-Zeile solange gehalten, bis eine Taste gedrückt wird; mehrere
     Tagestermine werden durch Tastendruck einzeln auf die Zeile gebracht und
     bleiben bis zum nächsten Tastendruck auf der Zeile stehen. Ohne diesen
     Parameter erscheint alles auf einen Schlag auf dem Bildschirm und Sie
     müssen zum Lesen mit der Zeile hochgehen.


 Sie können diese Parameter (jeweils mit Binde- oder Schrägstrich) in
 beliebiger Reihenfolge aneinanderreihen.



 3.Zusatzdateien

 Wenn Sie alle Optionen nutzen, legt das Programm folgende Zusatzdateien im
 UV TP selbständig an:

 TERMIN.DAT = Liste der aktiv verwalteten Termine

 TERMIN.BAK = BACKUP der TERMIN.DAT, ebenso TERMIN01.BAK und TERMIN02.BAK

 TERMIN.OLD = Liste der abgelaufenen Termine (vgl. hierzu Menüpunkt 4 des
    Termineditors)

 TERMIN.LOG = Registrierung
    - des Namens, mit dem Sie bei Aufruf begrüßt werden;
    - des Parameters, der bestimmt, wie häufig das automatische Backup der
      TERMIN.DAT gefertigt wird (sog. "Counter"; vgl. Punkt 4.3 dieser
      Anleitung);
    - von Tag und Uhrzeit der Programmaufrufe. Dadurch ist es möglich, daß
      Sie beim nächsten Aufruf auf zwischenzeitlich verstrichene Termine
      hingewiesen werden.
    Mit einem ASCII-Editor können Sie den Namen, mit dem Sie begrüßt werden,
    und den Backup-Counter ändern.

 TERMIN.NZB = Textdatei des Notizblocks

 ADRESSEN.1 enthält die Adreßdateien

 QSL.1 enthält die QSL-Adressen

 Hinzu kommt die datei
  TERMIN.FTG = Feiertagsliste (vgl. Punkt 4.6 dieser Anleitung), die von
  Ihnen selbst erstellt wird.


  4.Termineditor

 Er wird aufgerufen mit

 TERMIN -T

 oder:

 Termin -O


 je nach dem, ob Sie den automatischen Wochentagseintrag wünschen. Mit diesem
 Aufruf sollten Sie den TW auch in das Menü Ihres Arbeitsprogramms einbinden,
 um nicht für jeden Termineintrag in die DOS-Ebene wechseln zu müssen.

 Sie werden beim Erstaufruf des Termineditors nach Ihrem Namen gefragt, den Sie
 eintragen und mit Return bestätigen. Zukünftig werden Sie im Kopf des
 Bildschirms mit diesem Eintrag begrüßt.

 Sie können den Editor auch schon in der Startphase Ihres PC aufrufen:
 Wenn Ihnen die kommenden Termine angezeigt werden, brauchen Sie aus
 dieser Liste heraus nur t oder o einzugeben. Schon sind Sie im Menü
 und können sofort Änderungen oder Ergänzungen anbringen, ohne erst
 den Ablauf der AUTOEXEC.BAT abzuwarten, um den TW dann separat
 aufzurufen. Wenn Sie das TW-Menü dann mit Escape verlassen, kehren
 Sie nicht in die Terminanzeige zurück, sondern die Start-Datei wird
 weiter abgearbeitet.



 Die 9 Menüoptionen des Editors rufen Sie durch Anwahl mit den Cursortasten
 und Return oder durch Eingabe der Ziffer auf. Einige Menüpunkte haben
 Untermenüpunkte, die mit den Pfeiltasten und Return ausgewählt werden.


 4.1Terminliste


 1 = TERMIN.DAT Übersicht (F2/S=Suchbegr F3/ä=Ändern F4/L=Löschen)

   Diese Übersicht listet alle gespeicherten Termine auf. Sie sind
   chronologisch sortiert, beginnend mit den Terminen des aktuellen Tages.
   Der Cursor ist in Spalte 1 "geparkt", die Einträge beginnen in Spalte
   2. Das Datum steht in Spalten 2-9, Spalte 10 ist leer oder enthält
   ein Symbol für bestimmte Termintypen. Es folgen zweistellig das Kürzel für
   den Wochentag und zwei Leerzeichen, der Texteintrag beginnt in Spalte
   15.
   Die Liste kann mit den Cursor- und Pagetasten vorwärts und rückwärts
   durchgeblättert werden. Wenn Sie nach oben gehen, finden Sie die schon
   abgelaufenen, aber noch nicht in die TERMIN.OLD umgebuchten Termine. Mit
   Home bzw. End, Pos1 bzw. Pos2 oder mit Ctrl.Cursor up bzw. Ctrl.Cursor
   down können Sie an den Anfang bzw. das Ende der TERMIN.DAT gelangen. In
   der Statuszeile (Bildschirmzeile 1) steht der Dateiname und die laufende
   Nummer des Termins der Cursorzeile. Um zu erfahren, wieviele Termine Ihre
   Liste enthält, brauchen Sie nur ans Listenende zu springen und in der
   Statuszeile nachzulesen.

   Von Terminen mit einem zweizeiligen Text wird Ihnen hier nur die
   erste Zeile angezeigt. Wollen Sie auch die 2. Zeile lesen, müssen
   Sie ä oder F3 für "ändern" eingeben (s. nächten Absatz), ohne
   tatsächlich etwas zu verändern. Wenn Sie nach dem Lesen der 2.
   Zeile return eingeben, wird sie wieder unsichtbar.

   Außer diesem reinen Lesemodus gibt es noch drei Funktionen: suchen - ändern
   - löschen. Sie werden wahlweise mit F2, F3 und F4 oder mit den Buchstaben s,
   ä und l aufgerufen (PC- oder Braille-Tastatur). Diese Optionen können Sie
   stets in Bildschirmzeile 25 nachlesen.

   Das Suchen kann bei mehreren Fundstellen erneut durch F2 bzw. s mit Return
   aktiviert werden, da der eingegebene Suchbegriff erhalten bleibt. Ist das
   Ende der Datei erreicht, so ertönt ein Piepton.

   Drücken Sie F3 oder ä für Ändern, so springt der Cursor hinter das
   Ende des Eintrags, auf dem die Zeile gerade steht. Sie können mit
   Home- und End springen und mit den üblichen Editiertasten Ihren
   Eintrag korrigieren. Das geschieht normalerweise im Überschreiben-Modus. Mit
   F6 können sie in den Einfügen-Modus umschalten und wieder zurück. Die
   Änderung wird mit return gesichert. Auf der Zeile erscheint der
   korrigierte Eintrag in der Liste.

   Wählen Sie F4 oder l für Löschen, so erfolgt zunächst die
   Sicherheitsrückfrage, die Sie mit j oder n beantworten müssen. Wenn Sie j
   eingeben, wird die Zeile, auf der Sie stehen, gelöscht, und der nachfolgende
   Eintrag rückt hoch auf die Braillezeile. Sie sind wieder im Lesemodus der
   Liste.

   Sortierung: Die Liste ist nach dem Datum sortiert. Gibt es für einen Tag
   sowohl aktuelle als auch Wiederholungstermine, stehen die
   Wiederholungstermine - untereinander nach der Jahreszahl sortiert - hinter
   den aktuellen. Innerhalb der aktuellen Termine wird nach dem Texteintrag
   alphabetisch gelistet. Beginnen Sie den Texteintrag z.B. mit einer
   Zeitangabe (Stunden stets zweistellig schreiben!), dann erscheinen Ihre
   Termine auch in der richtigen Reihenfolge. Nach den mit Ziffern
   beginnenden Einträgen folgen die mit Buchstaben beginnenden.
   Termineinträge, die mit Menüpunkt 8 erzeugt wurden (Rastertermine), sind
   in der Spalte hinter dem Datum durch einen Punkt 6 gekennzeichnet; in der
   Sortierung erscheinen sie - auch wenn der Text mit einer Ziffer beginnt -
   erst nach den anderen aktuellen, aber noch vor den Wiederholungsterminen.
   Prioritätstermine sind ihrem Datum entsprechend einsortiert. Bei der
   Anzeige der aktuellen Termine werden sie als letzte
   "angeklingelt"; eine Zeile höher steht der Hinweis, daß es sich um einen
   noch nicht bestätigten Termin handelt.
   Zeitraumtermine stehen beim ersten Tag des Zeitraums vor allen anderen
   Terminen dieses Tages.


 4.2Suchen


 2 = Suche nach Terminen, Namen und Begriffen

   Es genügt auch die Eingabe eines Strings. Im Unterschied zur Suchfunktion
   von Menüpunkt 1 werden hier alle Einträge mit dem
   eingegebenen Suchbegriff oder String untereinander gelistet. Sie sollten
   deshalb darauf achten, daß Sie für gleichartige Termine auch die
   gleichen Begriffe oder Abkürzungen verwenden.

   In dieser Option können Sie Termine "ankreuzen" und dann löschen: Gehen
   Sie mit der Pfeiltaste auf den Eintrag, der aus der TERMIN.DAT gelöscht
   werden soll. Drücken Sie F4. Das Programm setzt in Spalte 1 dieser Zeile
   ein Nummernzeichen. So können Sie beliebig viele Termine Markieren. Gehen
   Sie dann mit beliebiger Taste weiter. Das Programm fragt Sie, ob die
   markierten Termine gelöscht werden sollen. Wenn Sie mit n antworten,
   bleibt Ihre Liste unverändert. Antworten Sie mit j, werden alle markierten
   Termine aus der TERMIN.DAT gelöscht. Sie kommen wieder zurück ins Menü.


 4.3Termineingabe


 3 = Eingabe von neuen Terminen

   Sie erhalten nacheinander die Vorgaben "Datum:" und "Text:" (Abschluß
   mit return)

   Datum:
   (Syntax: TT.MM.JJ), etwa: 24.09.95
   Durch ein Symbol, das unmittelbar hinter das Datum geschrieben wird,
   können Sie aus einem einfachen einen besonderen Termin machen:

   Wiederholungstermine:
   Soll der Termin jährlich wiederholt werden, so fügen Sie ein Sternchen an:
   24.09.53*
   Diese Option ist gut geeignet für Geburtstage und Gedenkdaten, denn Sie
   können auch eine zurückliegende Jahreszahl eintragen. Haben Sie
   den TW mit dem Parameter -o aufgerufen, so wird der zum Datum
   gehörende Wochentag dazugesetzt. Beachten Sie hierzu auch Menüpunkt 5.3!
   Wenn Sie die Geburtstage mit dem Geburtsjahr, aber ohne Wochentag haben
   möchten, dann rufen Sie den TW für das Erstellen der Geburtstagsliste
   einfach mit dem Parameter -t auf.

   Prioritätstermine:
   Ein Unterstrich hinter dem Datum (unbedingt mit Jahreszahl eintragen!)
   bewirkt, daß der Termin von seinem Datum an solange als "aktuell"
   behandelt wird, bis Sie ihn durch ein q quittieren.  Beispiel: Sie
   müssen die Blumen Ihrer Nachbarin gießen, bis sie wieder aus dem
   Krankenhaus zurück ist, oder Sie müssen unbedingt jemanden anrufen, wissen
   aber, daß er nicht immer zu erreichen ist. Dann tragen Sie den Fall in den
   TW ein und setzen hinter das Datum den Unterstrich. Der Termin wird Ihnen
   beim Start Ihres PC solange als aktuell angeklingelt, bis Sie ihn
   bestätigen. Geben Sie dazu ein q ein, wenn der angeklingelte Termin auf
   der Zeile steht. Dann wird der Unterstich aus der Terminliste gestrichen
   und der Termin als abgelaufen anerkannt. Solange nicht quittiert ist, wird
   der Termin auch nicht über Menüpunkt 4.2 in die TERMIN.OLD umgebucht.

   Zeitraumtermine:
   Möglich sind auch Terminangaben über Zeitabschnitte wie:
   28.09.95 - 04.10.95
   Sie werden dann während dieser Zeit täglich an die Terminkette erinnert.
   Wichtig ist das Leerzeichen vor und nach dem Bindestrich!

   Wochentag:
   Haben Sie den TW mit dem Parameter -t aufgerufen, wollen aber
   ausnahmsweise einmal den Wochentag dazu eingetragen bekommen, dann setzen
   Sie hinter das Datum einfach das Nummernzeichen.

   Text:
   Die Eingabe kann bis zu 2 Zeilen lang sein. Bei Spalte 70 kommt
   jeweils ein Piepton. Schreiben Sie nicht über die 2. Zeile
   hinaus, dasonst Ihr Eintrag nicht einwandfrei übernommen wird.
   Beim 160. Zeichen erfolgt ein weiterer Hinweiston.
   Mit Cursor up kommen Sie wieder hoch in die Datumszeile und können
   nachsehen oder ggf. korrigieren; mit return oder Cursor down kommen
   Sie zurück in die Text-Zeile.

   Speichern:
   Nach Abschluß mit return wird der Termin sofort gespeichert, und auf der
   zeile erscheint wieder "Datum:", so daß Sie den nächsten Termin eintragen
   können usw.; wollen Sie keine weiteren Termine eintragen, kommen sie mit
   ESCAPE oder return zurück ins Menü des Editors. Wenn Sie in der Datums-
   oder der Textzeile keinen Eintrag gemacht haben, wird der Termin nicht
   gespeichert, ebenso, wenn Sie statt mit return mit Escape
   abschließen.

   Hinweisfunktion:
   Enthält Ihre TERMIN.DAT unter dem eingegebenen Datum bereits einen
   Eintrag, so ertönt - wenn Sie die Datumseingabe bestätigt haben - ein
   Hinweiston. Auf der Zeile erscheint statt "text" der erste für diesen
   Tag schon vorhandene Eintrag. Sie befinden sich jetzt in einem Fenster mit
   Ihrer TERMIN.DAT und können darin arbeiten wie oben beschrieben (vgl.
   4.1). Sie können z.B. den vorhandenen Termin verschieben. Mit Escape
   kommen Sie zurück in den Eingabe-Modus; auf der Zeile erscheint die
   Eingabeaufforderung "Text".

   Dito-Funktion:
   Wollen Sie für einen Tag mehrere Termine eintragen oder haben Sie für
   verschiedene Daten denselben Text, ohne hierfür Menüpunkt 8 nutzen zu
   können, dann erleichtert Ihnen F8 die Arbeit. Den ersten Termin geben Sie
   ganz normal ein. Ab dem zweiten drücken Sie bei der Eingabeaufforderung,
   für die der vorige Eintrag wiederholt werden soll, die Taste F8. Das
   Programm schreibt den vorigen Eintrag hin und der Cursor steht an der
   nächsten Eingabeaufforderung. Wiederholen Sie also das Datum mit F8,
   Stehen Sie sofort bei "Text"; haben Sie den Texteintrag wiederholt, wird
   sofort gespeichert und Sie stehen wieder bei "Datum". Beim Wiederholen des
   Datums werden Sie natürlich nicht noch einmal darauf aufmerksam gemacht,
   daß für diesen Tag schon ein Eintrag da ist.

   Schreibweise:
   Mit der zweistelligen Eingabe von Tag, Monat und Jahr machen Sie
   nichts verkehrt. Sie können die Jahreszahl auch vierstellig
   eingeben z.B. 24.10.1996 oder 24.10.2005. Das Programm wandelt
   dann 1996 in 96 und 2005 in 05+ um.
   Das Programm akzeptiert aber auch verkürzte Schreibweisen:
   - Sie können die Jahreszahl weglassen, wenn der Termin im gleichen
   Jahr noch vor Ihnen liegt. Der Eintrag bekommt automatisch die
   aktuelle Jahreszahl angehängt. Sie müssen aber den Punkt hinter der
   Monatsangabe setzen und ohne ein Leerzeichen sofort return
   eingeben.
   - Sie können Tag und Monat einstellig eingeben, das Programm
   wandelt den Eintrag in die vollständige Schreibweise um. Aus 1.9.
   wird dann 01.09.96.
   Achtung! Bei Zeitraumterminen kann der Anfangstag im Kurzform, der
   Endtag muß in Langform mit Jahreszahl eingegeben werden.
   Wiederholungs- und Prioritätstermine können einstellig, müssen
   aber mit Jahreszahl eingegeben werden: 3.8.36* oder 12.9.96

   Eingabefehler:
   Der TW überprüft die Eingaben auf ihre Richtigkeit. Ein falsch
   geschriebenes oder ein nach dem Kalender unmögliches Datum wird nicht
   angenommen. Das gilt auch bei den anderen Menüpunkten.

   TERMIN.DAT:
   Beim ersten Abspeichern eines Termins richtet das Programm automatisch die
   Datei TERMIN.DAT ein und sortiert alle weiteren Termine hier ein.
   Die TERMIN.DAT ist für insgesamt 3000 Einträge ausgelegt. Sie können sie
   auch mit jedem anderen ASCII-Editor bearbeiten und z.B. eine fertige
   Terminliste von einem Kollegen oder aus einer Datenbank übernehmen und
   einfach an Ihre TERMIN.DAT anhängen. Die Termine werden dann einsortiert.
   Sie müssen nur darauf achten, daß keine Leerzeilen entstehen, die Einträge
   einzeilig und im vorgefundenen Format sind und das richtig geschriebene
   Datum in Spalte 1 der Zeile beginnt.

   Sicherungsdateien:
   Das Programm verfügt über ein dreifach gestaffeltes
   Sicherungssystem  für die TERMIN.DAT: Die TERMIN.BAK, die
   TERMIN01.BAK und die TERMIN02.BAK. Diese Vorsorge soll Sie davor
   bewahren, die Terminliste versehentlich zu beschädigen. Eine
   Beschädigung der TERMIN.DAT durch Fehlbedienung oder Programmfehler
   erscheinen zwar ausgeschlossen, aber ein so kostbarer Datenbestand
   muß immer gesichert werden. Damit aber das Backup nicht erstellt
   wird, ohne daß Sie die Möglichkeit hatten, sich vom ordnungsgemäßen
   Zustand der Datei zu überzeugen, gibt es eine doppelte Absicherung:
   Es wird nicht nach jeder Veränderung in der TERMIN.DAT gesichert,
   und es werden nach und nach 3 BAK-Dateien angelegt. Die TERMIN.LOG
   enthält einen einstellbaren Zähler (Standardeinstellung 3). Das
   Programm registiriert Ihre manuellen Eingriffe in die TERMIN.DAT,
   zählt zurück bis 0 und erstellt dann die TERMIN.BAK. Zugleich wird
   das "Zählwerk" wieder auf 3 gestellt. Gezählt werden nur die
   Programmaufrufe mit termin -t oder termin -o, nicht die
   einzelnen Einträge oder Änderungen, die Sie vorgenommen haben.
   Den Zahlenwert des Parameters können Sie verändern. Holen Sie dazu
   die Datei TERMIN.LOG in einen ASCII-Editor. In der ersten Zeile
   finden Sie im Abstand von zwei Leerzeichen hinter dem Namen, mit
   dem Sie begrüßt werden, folgenden Eintrag:

D    BAK_ACT: 3  BAK_CNT: 3

   Die 3 hinter ACT: ist der veränderbare Parameter; achten Sie beim
   Ändern unbedingt darauf, daß die Zeichen und Leerzeichen genau an
   der vorgesehenen Stelle bleiben und nicht verschoben werden. Die
   Ziffer hinter CNT: ist der Counter, also das erwähnte Zählwerk. Bei
   0 angekommen wird nach der nächsten Änderung das Backup gezogen.
   Ist die TERMIN.BAK bereits vorhanden, wird sie zunächst in
   TERMIN01.BAK umbenannt, diese in TERMIN02.BAK. So können Sie im
   Notfall auf 3 unterschiedlich alte Sicherungsdateien zurückgreifen.
    Tip aus der Praxis: Lassen Sie den Parameter in der TERMIN.LOG
   auf 3 stehen. das genügt völlig. Bei 0 würde jedesmal die Kette der
   Umbenennungen ausgelöst, und Sie könnten nicht so weit
   zurückgreifen.




 4.4AbgelaufeneTermine


 4 = Abgelaufene Termine
     4.1 TERMIN.OLD Übersicht  (F2/s=Suchbegr F3/ä=ändern F4/l=löschen)
     4.2 Löschen der schon abgelaufenen Termine aus der TERMIN.DAT und
       Abspeichern dieser Einträge in TERMIN.OLD

   4.1 Ebenso wie bei 1 = TERMIN.DAT Übersicht können Sie im Unterpunkt 4.1
   dieses Menüpunkts in die Liste der abgelaufenen Termine gehen und, wie
   oben geschildert, editieren.

   4.2 Dieser Menüpunkt dient zur Säuberung der TERMIN.DAT. Wenn Sie ihn
   aufrufen, werden alle abgelaufenen Termine aus der TERMIN.DAT entfernt und
   kontinuierlich in der TERMIN.OLD abgelegt, die das Programm selbst
   einrichtet. Nicht mit "umgebucht" werden natürlich die in der TERMIN.DAT
   mit dem Unterstrich markierten Prioritätstermine und die mit einem
   Sternchen gekennzeichneten Wiederholungstermine, damit sie Ihnen auch in
   den kommenden Jahren wieder angezeigt werden können. So können Sie noch
   nach Jahren Ihre früheren Termine nachsehen, ohne sich die TERMIN.DAT mit
   den alten Einträgen zu blockieren.


 4.5Überblick


 5 = Datums/Wochentagberechnung

   5.1 Monatskalender
   Hiermit können Sie sich gezielt ganze Monate in ihrer Verteilung auf die
   Wochentage ansehen. Voreingestellt ist das aktuelle Jahr und der aktuelle
   Monat. Durch zweimaliges Return erreichen Sie also diese Listung. Für
   andere Jahre und andere Monate überschreiben Sie einfach diese Voreingaben
   und geben Return.

   Für jede Woche wird eine Zeile verwendet. Hinter dem Datum des Sonntags
   finden Sie die Nummer der Kalenderwoche, z.B. KW43.

   Ist für einen Tag dieses Monats ein Termin vorgemerkt, erscheint der
   dazugehörende Kennbuchstabe direkt hinter der Zahl: für
   Wiederholungstermine ein w, für Zeitraumtermine ein z, für Rastertermine
   ein r und für andere (auch Prioritäts-) Termine ein t. Haben Sie an einem
   Tag von jedem Typ etwas, erscheinen alle vier Buchstaben; kommt derselbe
   Termintyp an einem Tag mehrfach vor, erscheit der Buchstabe nur einmal. Sie
   können aber auf einen Blick feststellen, welche Tage Sie in diesem Monat noch
   frei haben. Für zurückliegende Zeiträume funktioniert diese Anzeige nur
   solange, wie die Termine noch in der TERMIN.DAT und noch nicht in der
   TERMIN.OLD stehen.

   Mit Escape gelangen Sie jeweils nur eine Ebene zurück, so daß Sie
   rasch eine weitere Monatsübersicht aufrufen können. Mit nochmaligem
   Escape kommen Sie wieder ins Hauptmenü.

 5.2 Berechnung des Wochentags
   Der zu einem Datum der Jahre 1901 - 2064 gehörende Wochentag wird
   angezeigt. Die Jahreszahl ist 4stellig einzugeben, also etwa: 1922.

   5.3 = Wochentage der Sterntermine für dieses Jahr aktualisieren
   Die Sterntermine werden grundsätzlich ohne Wochentag in die Terminliste
   übernommen, weil er sich ja jedes Jahr ändert. Und wenn Sie als Jahreszahl
   auch gleich das Geburtsjahr eingegeben haben (also z.B. 22.04.42*),
   dürfte das Programm schon der Logik wegen nur den Wochentag des
   tatsächlichen Geburtstags angeben, der dann unverändert bleibt.
   Möchten Sie aber gern wissen, auf welchen Wochentag das Wiegenfest in
   diesem Jahr fällt, ohne sich diese Angabe einzeln über Menüpunkt 5.2 zu
   holen, hilft Ihnen diese Option. Das Programm trägt bei sämtlichen
   Sternterminen die aktuelle Jahreszahl ein und fügt den dazugehörenden
   Wochentag an. Im nächsten Januar wiederholen Sie diesen Schritt.
   Jahreszahl und Wochentag werden wieder aktualisiert.
   Achtung: Wenn Sie in Ihrer TERMIN.DAT zunächst die Geburtsjahre stehen
   hatten und jetzt auf das andere System umsteigen wollen, müssen Sie
   zunächst die Geburtsjahre in die Textzeile übernehmen, sonst gehen ihnen
   diese Angaben verloren.



 4.6 Feiertage


 6 = Feiertage

 6.1 = Feiertage

    Hier können die wichtigsten Feiertage eines Jahres zwischen
    1901 und 2064 aufgelistet werden. Die Jahreszahl ist 4stellig
    einzugeben. Bei Feiertagen, die nicht automatisch auf einen
    Sonntag fallen (z.B. Weihnachten), ist hinter der Bezeichnung des
    Feiertages zusätzlich der Wochentag angegeben. Auch hier ist das
    aktuelle Jahr vorgegeben.
    Mit Escape gelangen Sie jeweils nur eine Ebene zurück, so daß Sie
    rasch eine spätere oder frühere Feiertagsliste aufrufen können.
    Mit nochmaligem Escape kommen Sie wieder ins Hauptmenü.

    Erweiterung der Liste:
    Wenn Sie den Wunsch haben, besondere Gedenk- und Feiertage in den
    Feiertagskalender aufzunehmen, so erstellen Sie sich mit einem
    ASCII-Editor eine Datei, die Sie als TERMIN.FTG in das UV TP
    aufnehmen. Ihre Einträge werden in die Liste der vorgegebenen
    Feiertage einsortiert. Ab Spalte 50 wird der dazugehörende
    Wochentag angezeigt.  Die Syntax Ihrer TERMIN.FTG muß so
    aussehen:  02.02. - Mariä Lichtmeß  Nach dem letzten Eintrag
    in die TERMIN.FTG dürfen Sie kein return eingeben, sonst entsteht
    am Ende der Liste eine Leerzeile, die das Programm stört.

 6.2 = Abspeichern der diesjährigen Feiertage in die TERMIN.DAT
    Wenn Sie diesen Punkt aufrufen, werden alle Feiertage, die das Programm
    kennt, und die, die Sie in Ihre TERMIN.FTG aufgenommen haben, in Ihre
    TERMIN.DAT einsortiert. Haben Sie das Programm mit termin -o
    gestartet, dann werden natürlich auch die Wochentage dazugesetzt. Sie
    haben dann die Feiertage als ganz gewöhnliche Termine in Ihrer Liste
    stehen und werden z.B. beim Eintragen neuer Termine darauf aufmerksam
    gemacht.
    Rufen Sie diesen Punkt nur einmal zu Beginn eines jeden Jahres auf, denn
    bei jedem weiteren Aufruf würde der komplette Feiertagsbestand erneut in
    die TERMIN.DAT übernommen.



 4.7Adreßverwaltung


 7 = Adreßdateiverwaltung
   7.1 Adressen
   7.2 QSL-Datei

 Hier können Sie Adressen und Telefonnummern ablegen. Beim Aufruf der
 Unterpunkte erhalten Sie jeweils ein Untermenü, das dem Menü des
 Termin-Editors entspricht. Es gelten die gleichen Editierfunktionen wie
 sonst auch in diesem Programm.

 Für die unter 7.1 erfaßten Daten legt das Programm die Datei ADRESSEN.1 an,
 für die unter 7.2 die Datei QSL.1.


 4.8Rastertermine


 8 = Terminberechnung und Eintragung

   Hier können Sie turnusmäßig wiederkehrende Termine berechnen und
   automatisch in die TERMIN.DAT eintragen lassen. Es gibt vier
   Varianten (Unterpunkte 8.1 - 8.4). Die Eingabefelder sind jeweils links am
   Zeilenanfang (Cursor in Spalte 1). Die dazugehörende Anweisung steht rechts
   daneben, für Benutzer einer kurzen Braillezeile ein Vorteil.
   Tragen Sie die erforderlichen Angaben ein (Ausgangsdatum - soweit
   gefragt - mit Jahreszahl!). Nun folgt die Aufforderung zur Texteingabe, wie
   wir sie vom menüpunkt 3 her kennen. Zugleich finden Sie weiter oben auf
   dem Bildschirm eine Tabelle mit den Daten, die sich aus Ihren Eingaben
   errechnen.  Wenn Sie jetzt den Text eintragen und mit return bestätigen,
   werden nach einer Sicherheitsrückfrage Ihre Termine in die TERMIN.DAT
   übernommen. Geben Sie keinen Text ein oder beantworten Sie die
   Sicherheitsrückfrage mit n, so werden die Termine nicht abgespeichert. Sie
   können sich also die Termine nur anzeigen lassen und verschiedene
   Alternativen vergleichen.
   Die so erzeugten Einträge in die TERMIN.DAT werden vom Programm hinter der
   Jahreszahl durch ein Apostroph (Punkt 6) und in der Monatsübersicht
   (Menüpunkt 5) durch ein r gekennzeichnet ("Rastertermine").
   Die Tabelle mit den errechneten Terminen können Sie nur ansehen, aber
   nicht verändern. Einen einzelnen Termin, von dem Sie wissen, daß er
   ausfällt, weil er z.B. auf einen Feiertag fällt, müssen Sie von Hand
   wieder aus der TERMIN.DAT löschen. Beim Speichern der mit diesem Menüpunkt
   erzeugten Einträge entfällt auch die Hinweisfunktion auf bereits
   voreingetragene Termine.


  8.1 Festes Zeitraster
  Hier lassen Sie Termine berechnen, die nur einmal im Monat an festen
  Wochentagen vorkommen, z.B. der Kegelabend an jedem dritten Freitag im
  Monat.  Das Programm fragt nacheinander  das Jahr, den Wochentag und die
  Woche des Monats ab.  Das aktuelle Kalenderjahr ist voreingetragen, Sie
  können es ändern. Für den Wochentag geben Sie die beiden Anfangsbuchstaben
  ein, also Fr. Für die Woche im Monat genügt die einstellige Zahl, also 3.

  Es folgt die Aufforderung zur Texteingabe und die Übersicht Ihrer
  Kegelabende für das ganze Jahr weiter oben auf dem Bildschirm. Vollenden
  Sie nun Ihren Eintrag oder brechen Sie ihn ab.

  8.2 Bewegliches Zeitraster
  Man verwendet diesen Punkt für periodisch wiederkehrende Termine wie z.B.
  einen Kegelabend, der alle 4 Wochen ansteht.
  Das Programm fragt nach dem Ausgangstermin, von dem an sich der Rhythmus
  berechnet. Z.B. 13.11.95
  Danach geben Sie das gewünschte zeitintervall nach Tagen oder Wochen
  ein. z.B. 4W für vier Wochen oder 10T für zehn Tage.
  Schließlich werden Sie nach der Zahl der gewünschten Termine gefragt,
  die Sie nach Bedarf eintragen. Der Ausgangstermin zählt dabei mit.
  Beispiel: Ein Volkshochschulkurs, der alle 14 Tage stattfindet, umfaßt
  12 Abende. Sie tragen den Ausgangstermin ein, geben als Intervall 2w an
  und als Zahl der Termine 12.
  Die Höchstmenge der Termine ist 99. Sie können hier auch den
  Jahreswechsel überschreiten.
  Aufforderung zum Texteintrag und Übersicht wie oben.

  8.3 Zeitspannentermin
  Dieser Punkt dient zur Bestimmung eines bestimmten Tagesabstandes. Sie
  können hiermit Fristen berechnen und überwachen.
  Sie werden wieder nach dem Ausgangstermin gefragt und tragen bei der
  nächsten Eingabeaufforderung die zeitspanne ein, z.B. 40. Der Index T für
  Tage kann entfallen.
  Aufforderung zum Texteintrag und Übersicht wie oben.

 8.4 Monatliches Zeitraster
  Sie können sich hier feste Monatsdaten vormerken. nach der Eingabe des
  Ausgangtermins werden Sie nach den gewünschten Monatsintervallen und der
  Anzahl der zu speichernden Termine gefragt. Anschauen der Termine,
  Texteingabe und Bestätigung folgen.
  Sie merken mit dieser Option Termine vor, die in einem festen
  Monatsrhythmus immer am gleichen Tag anstehen, z.B. eine Zahlung, die alle
  drei Monate am 15. fällig ist.
  Achtung: Um das Programm nicht unnötig zu komplizieren, wurde bei diesem
  Menüpunkt auf eine "Logikkontrolle" verzichtet. Wenn Sie also den 31.01.95
  als Ausgangstermin eingeben und 12 Rastertermine verlangen, erhalten Sie
  alle Monate des Jahres mit dem Tagesdatum 31 angezeigt.

  Falls Sie den Termin-Editor mit dem Parameter -O aufgerufen haben,
  erhalten auch die Rastertermine den Eintrag des Wochentags.



 4.9Notizblock


 9 = Notizblock

  Hier haben Sie die Möglichkeit, ganz normalen Text zu schreiben,
  sich also Notizen zu machen und sie zu lesen, ohne den TW zu
  verlassen. Das Programm legt automatisch die Datei "TERMIN.NZB" an,
  in der der Text im ASCII-Format abgelegt wird.

  Diese Datei können Sie natürlich auch in jedem anderen Editor
  bearbeiten und sich so Notizen für den TW machen, ohne Ihr
  Arbeitsprogramm verlassen zu müssen.

  Bei Aufruf erscheint zunächst die Liste der kommenden Termine, wie
  sie mit dem Parameter -kx oder -ktx voreingestellt ist; mit
  einer beliebigen Taste kommen Sie in Ihre Notizen.

  Außer über dieses Menü können Sie den Notizblock auch mit dem Befehl

  termin -b
  von der DOS-Ebene aus starten. Der Aufruf des Editors und des
  Notizblocks kann aber nicht in derselben Befehlszeile erfolgen.

  Wenn Sie beim Aufruf der Terminüberwachung z.B. in der AUTOEXEC.BAT
  den Parameter -b setzen, wird Ihnen nach Verlassen der Liste mit
  den kommenden Termine der Text der Datei TERMIN.NZB angezeigt, und
  sie können editieren.

  Im Rahmen des TW haben sie hier nur einfache, aber hinreichende
  Editiermöglichkeiten:

  Beim Aufruf des Notizblocks stehen Sie mit dem Cursor am Anfang der
  ersten Zeile. Innerhalb schon vorhandener Notizen können Sie mit F2
  nach einem Stichwort suchen, mit F5 eine Leerzeile einfügen und mit
  F4 eine ganze Zeile löschen.
  Achtung! Beim Zeilenlöschen mit F4 erfolgt beim Notizblock keine
  Sicherheitsrückfrage. Die Zeile wird mit dem Druck auf F4 sofort
  gelöscht!

  Eine Übersicht über diese Funktionen finden Sie in Bildschirmzeile 25.

  Sie können die Editiertasten Backspace, Insert und delete verwenden. Den
  Cursor können Sie an den Zeilenanfang bzw. das Zeilenende mit Ctrl. plus
  Cursor links bzw. Cursor rechts führen; In die erste bzw. letzte Zeile des
  Notizblocks springen Sie mit Ctrl. plus Cursor up bzw. Cursor down oder mit
  den Tasten Home bzw. End.

  Mit Alt-D können Sie Ihre Notiz mit Datum und Uhrzeit versehen.

  Beim Schreiben ertönt in Spalte 74 ein Signalton zum Zeichen, daß
  Sie sich kurz vor dem Zeilenende befinden. Schreiben Sie ruhig
  weiter, falls Sie keine Worttrennung machen wollen. Der Notizblock
  verfügt über einen automatischen Zeilenumbruch.

  Verlassen Sie den Notizblock mit Escape. Ihre Notizen werden ohne weitere
  Rückfrage gespeichert. Sie kommen direkt zu Ihrem Ausgangspunkt zurück, je
  nach dem, ob Sie den Notizblock von der DOS-Ebene oder aus dem TW-Editor
  gestartet haben.




 Schlußbemerkung

 Der Programmautor und seine Test-Anwender sind sich darin einig, daß
 der TW mit seiner Version 3.0 vorerst am Ende der Entwicklung
 angekommen ist. Alle grundlegenden Wünsche der Anwender wurden
 realisiert. Lediglich der Gedanke, den TW speicherresident zu
 gestalten, wurde vorerst fallen gelassen, da die Verwirklichung zu
 viele Risiken mit sich bringen würde.

 Dennoch: Sollten Sie bei der Nutzung des Terminwächters Fehler
 entdecken oder Verbesserungsvorschläge haben, so gebe ich diese gern
 an den Autor weiter. Bitte, schreiben Sie mir oder rufen Sie mich an.

 Gerhard Reiter, Drosselweg 6, 30559 Hannover, Telef. 0511/9525555



viel Spaß auch mit diesem Programm, welches ich als binärfile einspiele vy 73
de Marco df1nd@db0mak.bay.deu.eu
sprachmailbox df1nd @092db0zb, usernummer 107


Read previous mail | Read next mail


 30.09.2026 17:23:17lGo back Go up